.. note *_include.rst is a naming convention in conf.py

.. |tutorial_title| replace:: ORM Querying Guide

.. topic:: |tutorial_title|

      This page is part of the :doc:`index`.

      Previous: |prev|   |   Next: |next|

.. footer_topic:: |tutorial_title|

      Next Query Guide Section: |next|

